#ifndef ACTOR_H
#define ACTOR_H

#include <memory>
#include <SDL3/SDL_rect.h>
#include "../DataStructures/Vector2D.h"
#include "../DataStructures/Hitbox.h"

class Actor : public std::enable_shared_from_this<Actor>
{
public:
    virtual ~Actor() {};
    //virtual void Update(float deltaTime) {};
    void SetPosition(Vector2D position);
    void MoveBy(Vector2D velocity);

    Vector2D GetPosition() {return m_Position;}
    Hitbox GetMovementHitbox() {return m_MoveHitbox;}
    Hitbox GetCombatHitbox() {return m_CombatHitbox;}

    friend class ActorFactory;
protected:
    virtual void Init() {};
    Actor(Vector2D position, Hitbox moveHitbox, Hitbox combatHitbox) : m_Position(position), m_MoveHitbox(moveHitbox), m_CombatHitbox(combatHitbox) {};

    Vector2D m_Position;
    Hitbox m_MoveHitbox;
    Hitbox m_CombatHitbox;
    std::shared_ptr<InputComponent> m_InputComponent; //Input or AI
    std::shared_ptr<MoveComponent> m_MoveComponent;
    std::shared_ptr<ActionComponent> m_ActionComponent; //Skills, hit with Axe, Fiery rush,...
    std::shared_ptr<SpriteComponent> m_SpriteComponent; //Sprites or anim Sprites

    //every other action needs a sprite
    //move needs input, input maybe needs move?
    //action needs input, input maybe needs action
    //all of them don't belong into the base Actor
    //Actor, Visible Actor, ActionActor???
    //Base Component pointer in Vector?
    //Dialogue Component? - makes sense
    //Interaction component? - allows interaction - dialogue, open chest, read sign (is dialogue?)
    //Damage component for taking damage? part of interaction? also talking?
};

#endif // ACTOR_H
